---
title: wls dynamic cluster
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a dynamic cluster in an WebLogic domain.

Here is an example on how you should use this:

    wls_dynamic_cluster{'DynamicCluster':
      ensure                 => 'present',
      calculated_listen_port => '0',  # '0' or '1'
      maximum_server_count   => '2',
      nodemanager_match      => 'Node1,Node2',
      server_name_prefix     => 'DynCluster-',
      server_template_name   => 'ServerTemplateWeb',
    }

In this example you are managing a dynamic cluster in the default domain. When you want to
manage a dynamic cluster in a specific domain, you can use:

    wls_dynamic_cluster{'my_domain/DynamicCluster':
      ensure                 => 'present',
      calculated_listen_port => '0',  # '0' or '1'
      maximum_server_count   => '2',
      nodemanager_match      => 'Node1,Node2',
      server_name_prefix     => 'DynCluster-',
      server_template_name   => 'ServerTemplateWeb',
    }

Check the [WebLogic documentation](https://docs.oracle.com/middleware/1212/wls/INTRO/clustering.htm#INTRO336) for more information
about configuring and managing datasources.

## Attributes



Attribute Name                                                                                            | Short Description                                                                                                                                                |
--------------------------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------- |
[calculated_listen_port](#wls_dynamic_cluster_calculated_listen_port)                                     | Set managed server ports is auto calculated
                                                                                                                     |
[calculated_listen_ports](#wls_dynamic_cluster_calculated_listen_ports)                                   | Specifies whether listen ports are calculated.                                                                                                                   |
[calculated_machine_names](#wls_dynamic_cluster_calculated_machine_names)                                 | The CalculatedMachineNames attribute controls how server instances in a dynamic cluster are assigned to a machine.                                               |
[cluster_name](#wls_dynamic_cluster_cluster_name)                                                         | The cluster name
                                                                                                                                                |
[domain](#wls_dynamic_cluster_domain)                                                                     | With this parameter, you identify the domain, where your objects is in.                                                                                          |
[dynamic_cluster_cooloff_period_seconds](#wls_dynamic_cluster_dynamic_cluster_cooloff_period_seconds)     | Get the cool-off period (in seconds) used by the Elasticity Framework while performing scale up or scale down operations.                                        |
[dynamic_cluster_shutdown_timeout_seconds](#wls_dynamic_cluster_dynamic_cluster_shutdown_timeout_seconds) | Get the timeout period (in seconds) used by the Elasticity Framework while gracefully shutting down a server.                                                    |
[dynamic_cluster_size](#wls_dynamic_cluster_dynamic_cluster_size)                                         | Get the current size of the dynamic cluster (the number of dynamic server instances allowed to be created).                                                      |
[ensure](#wls_dynamic_cluster_ensure)                                                                     | The basic property that the resource should be in.                                                                                                               |
[ignore_sessions_during_shutdown](#wls_dynamic_cluster_ignore_sessions_during_shutdown)                   | Indicates if the Elasticity Framework should ignore inflight HTTP sessions while shutting down servers.                                                          |
[machine_match_expression](#wls_dynamic_cluster_machine_match_expression)                                 | Get the machine tag expression to use when selecting machine names.                                                                                              |
[machine_match_type](#wls_dynamic_cluster_machine_match_type)                                             | Get the machine tag expression to use when selecting machine names.                                                                                              |
[machine_name_match_expression](#wls_dynamic_cluster_machine_name_match_expression)                       | The expression is used when determining machines to use for server assignments.                                                                                  |
[max_dynamic_cluster_size](#wls_dynamic_cluster_max_dynamic_cluster_size)                                 | Get the upper bound on the DynamicClusterSize that the Elasticity Framework is allowed to assign to DynamicClusterSize.                                          |
[maximum_dynamic_server_count](#wls_dynamic_cluster_maximum_dynamic_server_count)                         | Get the maximum number of server instances allowed to be created.                                                                                                |
[maximum_server_count](#wls_dynamic_cluster_maximum_server_count)                                         | The maximum server count of this cluster
                                                                                                                        |
[min_dynamic_cluster_size](#wls_dynamic_cluster_min_dynamic_cluster_size)                                 | Get the minimum number of running server instances that the Elasticity Framework will attempt to keep in the dynamic cluster.                                    |
[name](#wls_dynamic_cluster_name)                                                                         | The name.                                                                                                                                                        |
[nodemanager_match](#wls_dynamic_cluster_nodemanager_match)                                               | The nodemanager match of this dynamic cluster
                                                                                                                   |
[notes](#wls_dynamic_cluster_notes)                                                                       | Optional information that you can include to describe this configuration.                                                                                        |
[provider](#wls_dynamic_cluster_provider)                                                                 | resource.                                                                                                                                                        |
[server_name_prefix](#wls_dynamic_cluster_server_name_prefix)                                             | The server name prefix of this dynamic cluster
                                                                                                                  |
[server_template](#wls_dynamic_cluster_server_template)                                                   | The server template used to create dynamic servers.                                                                                                              |
[server_template_name](#wls_dynamic_cluster_server_template_name)                                         | The server template name of this cluster
                                                                                                                        |
[tags](#wls_dynamic_cluster_tags)                                                                         | Return all tags on this Configuration MBean
                                                                                                                     |
[timeout](#wls_dynamic_cluster_timeout)                                                                   | Timeout for applying a resource.                                                                                                                                 |
[wait_for_all_sessions_during_shutdown](#wls_dynamic_cluster_wait_for_all_sessions_during_shutdown)       | Indicates if the Elasticity Framework should wait for all (persisted and non-persisted) HTTP sessions during inflight work handling while shutting down servers. |




### calculated_listen_port<a name='wls_dynamic_cluster_calculated_listen_port'>

Set managed server ports is auto calculated

Valid values are `absent`, `0`, `1`. 

[Back to overview of wls_dynamic_cluster](#attributes)

### calculated_listen_ports<a name='wls_dynamic_cluster_calculated_listen_ports'>

Specifies whether listen ports are calculated.

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       calculated_listen_ports => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:calculated_listen_ports']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_dynamic_cluster](#attributes)

### calculated_machine_names<a name='wls_dynamic_cluster_calculated_machine_names'>

The CalculatedMachineNames attribute controls how server instances in a dynamic cluster are assigned to a machine. If the attribute is not set, then the dynamic servers will not be assigned to a machine. If the attribute is set, then the MachineNameMatchExpression attribute is used to select the set of machines to use for the dynamic servers.

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       calculated_machine_names => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:calculated_machine_names']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_dynamic_cluster](#attributes)

### cluster_name<a name='wls_dynamic_cluster_cluster_name'>

The cluster name



[Back to overview of wls_dynamic_cluster](#attributes)

### domain<a name='wls_dynamic_cluster_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_dynamic_cluster](#attributes)

### dynamic_cluster_cooloff_period_seconds<a name='wls_dynamic_cluster_dynamic_cluster_cooloff_period_seconds'>

Get the cool-off period (in seconds) used by the Elasticity Framework while performing scale up or scale down operations. If a scale up or scale down operation was performed, subsequent requests for scale up or down operations will be ignored by the Elasticity Framework during this period.

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       dynamic_cluster_cooloff_period_seconds => '900'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:dynamic_cluster_cooloff_period_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_dynamic_cluster](#attributes)

### dynamic_cluster_shutdown_timeout_seconds<a name='wls_dynamic_cluster_dynamic_cluster_shutdown_timeout_seconds'>

Get the timeout period (in seconds) used by the Elasticity Framework while gracefully shutting down a server. If the server does not shut down before the specified timeout period, the server will be forcibly shut down. With a negative time value, no timeout will be applied.

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       dynamic_cluster_shutdown_timeout_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:dynamic_cluster_shutdown_timeout_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_dynamic_cluster](#attributes)

### dynamic_cluster_size<a name='wls_dynamic_cluster_dynamic_cluster_size'>

Get the current size of the dynamic cluster (the number of dynamic server instances allowed to be created). The specified number of server instances are dynamically added to the configuration at runtime and associated ServerLifeCycleRuntimeMBeans are created.

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       dynamic_cluster_size => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:dynamic_cluster_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_dynamic_cluster](#attributes)

### ensure<a name='wls_dynamic_cluster_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_dynamic_cluster](#attributes)

### ignore_sessions_during_shutdown<a name='wls_dynamic_cluster_ignore_sessions_during_shutdown'>

Indicates if the Elasticity Framework should ignore inflight HTTP sessions while shutting down servers.

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       ignore_sessions_during_shutdown => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:ignore_sessions_during_shutdown']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_dynamic_cluster](#attributes)

### machine_match_expression<a name='wls_dynamic_cluster_machine_match_expression'>

Get the machine tag expression to use when selecting machine names.  If the MachineMatchType is "name", each value will either match a machine name exactly or, if specified with a trailing '*' suffix, will match multiple machine names. If the MachineMatchType is "tag", the values will match all of the machines that have all of the tag values.

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       machine_match_expression => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:machine_match_expression']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_dynamic_cluster](#attributes)

### machine_match_type<a name='wls_dynamic_cluster_machine_match_type'>

Get the machine tag expression to use when selecting machine names.  If the MachineMatchType is "name", each value will either match a machine name exactly or, if specified with a trailing '*' suffix, will match multiple machine names. If the MachineMatchType is "tag", the values will match all of the machines that have all of the tag values.

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       machine_match_type => 'name'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:machine_match_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_dynamic_cluster](#attributes)

### machine_name_match_expression<a name='wls_dynamic_cluster_machine_name_match_expression'>

The expression is used when determining machines to use for server assignments. If null, then all machines in the domain are used. If a expression is provided, then only the machines in the domain that match the expression will be used when assigning machine names to dynamic servers.  The expression is a comma separated set of values that specify the machines to match. Each value will either match a machine name exactly or if specified with a trailing '*' suffix, the value will match multiple machine names.

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       machine_name_match_expression => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:machine_name_match_expression']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_dynamic_cluster](#attributes)

### max_dynamic_cluster_size<a name='wls_dynamic_cluster_max_dynamic_cluster_size'>

Get the upper bound on the DynamicClusterSize that the Elasticity Framework is allowed to assign to DynamicClusterSize.

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       max_dynamic_cluster_size => '8'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:max_dynamic_cluster_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_dynamic_cluster](#attributes)

### maximum_dynamic_server_count<a name='wls_dynamic_cluster_maximum_dynamic_server_count'>

Get the maximum number of server instances allowed to be created. This value should be set to the number of servers expected to be in the cluster. The specified number of servers are dynamically added to the configuration at runtime and associated ServerLifeCycleRuntimeMBeans are created.

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       maximum_dynamic_server_count => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:maximum_dynamic_server_count']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_dynamic_cluster](#attributes)

### maximum_server_count<a name='wls_dynamic_cluster_maximum_server_count'>

The maximum server count of this cluster



[Back to overview of wls_dynamic_cluster](#attributes)

### min_dynamic_cluster_size<a name='wls_dynamic_cluster_min_dynamic_cluster_size'>

Get the minimum number of running server instances that the Elasticity Framework will attempt to keep in the dynamic cluster.

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       min_dynamic_cluster_size => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:min_dynamic_cluster_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_dynamic_cluster](#attributes)

### name<a name='wls_dynamic_cluster_name'>

The name.



[Back to overview of wls_dynamic_cluster](#attributes)

### nodemanager_match<a name='wls_dynamic_cluster_nodemanager_match'>

The nodemanager match of this dynamic cluster



[Back to overview of wls_dynamic_cluster](#attributes)

### notes<a name='wls_dynamic_cluster_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_dynamic_cluster](#attributes)

### provider<a name='wls_dynamic_cluster_provider'>

The specific backend to use for this `wls_dynamic_cluster`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage all the WebLogic dynamic cluster via regular WLST



[Back to overview of wls_dynamic_cluster](#attributes)

### server_name_prefix<a name='wls_dynamic_cluster_server_name_prefix'>

The server name prefix of this dynamic cluster



[Back to overview of wls_dynamic_cluster](#attributes)

### server_template<a name='wls_dynamic_cluster_server_template'>

The server template used to create dynamic servers.

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       server_template => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:server_template']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_dynamic_cluster](#attributes)

### server_template_name<a name='wls_dynamic_cluster_server_template_name'>

The server template name of this cluster



[Back to overview of wls_dynamic_cluster](#attributes)

### tags<a name='wls_dynamic_cluster_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_dynamic_cluster](#attributes)

### timeout<a name='wls_dynamic_cluster_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_dynamic_cluster](#attributes)

### wait_for_all_sessions_during_shutdown<a name='wls_dynamic_cluster_wait_for_all_sessions_during_shutdown'>

Indicates if the Elasticity Framework should wait for all (persisted and non-persisted) HTTP sessions during inflight work handling while shutting down servers.

An example on how to use this:

    wls_dynamic_cluster {a_wls_dynamic_cluster :
       ...
       wait_for_all_sessions_during_shutdown => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_dynamic_cluster:wait_for_all_sessions_during_shutdown']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_dynamic_cluster](#attributes)
