---
title: wls workmanager constraint
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage work manager constraints in an WebLogic domain.

Here is an example on how you should use this:

    wls_workmanager_constraint { 'CapacityConstraint':
      ensure          => 'present',
      constrainttype  => 'Capacity',
      constraintvalue => '20',
      target          => ['WebCluster'],
      targettype      => ['Cluster'],
    }

In this example you are managing a work manager contraint in the default domain. When you want to
manage a work manager contraint in a specific domain, you can use:

    wls_workmanager_constraint { 'my_domain/MaxThreadsConstraint':
      ensure          => 'present',
      constrainttype  => 'MaxThreadsConstraint',
      constraintvalue => '5',
      target          => ['WebCluster'],
      targettype      => ['Cluster'],
    }

Here are some more examples:

    wls_workmanager_constraint { 'MinThreadsConstraint':
      ensure          => 'present',
      constrainttype  => 'MinThreadsConstraint',
      constraintvalue => '2',
      target          => ['WebCluster'],
      targettype      => ['Cluster'],
    }
    wls_workmanager_constraint { 'FairShareReqClass':
      ensure          => 'present',
      constrainttype  => 'FairShareRequestClasses',
      constraintvalue => '50',
      target          => ['WebCluster'],
      targettype      => ['Cluster'],
    }

## Attributes



Attribute Name                                                                         | Short Description                                                       |
-------------------------------------------------------------------------------------- | ----------------------------------------------------------------------- |
[constrainttype](#wls_workmanager_constraint_constrainttype)                           | Workmanager constraint name
                                            |
[constraintvalue](#wls_workmanager_constraint_constraintvalue)                         | The value of a workmanager constraint
                                  |
[domain](#wls_workmanager_constraint_domain)                                           | With this parameter, you identify the domain, where your objects is in. |
[ensure](#wls_workmanager_constraint_ensure)                                           | The basic property that the resource should be in.                      |
[name](#wls_workmanager_constraint_name)                                               | The name.                                                               |
[provider](#wls_workmanager_constraint_provider)                                       | resource.                                                               |
[target](#wls_workmanager_constraint_target)                                           | An array of target names.                                               |
[targettype](#wls_workmanager_constraint_targettype)                                   | An array of target types.                                               |
[timeout](#wls_workmanager_constraint_timeout)                                         | Timeout for applying a resource.                                        |
[workmanager_constraint_name](#wls_workmanager_constraint_workmanager_constraint_name) | The workmanager constraint name
                                        |




### constrainttype<a name='wls_workmanager_constraint_constrainttype'>

Workmanager constraint name

Valid values are `absent`, `MaxThreadsConstraint`, `MinThreadsConstraint`, `Capacity`, `FairShareRequestClass`, `ResponseTimeRequestClass`. 

[Back to overview of wls_workmanager_constraint](#attributes)

### constraintvalue<a name='wls_workmanager_constraint_constraintvalue'>

The value of a workmanager constraint



[Back to overview of wls_workmanager_constraint](#attributes)

### domain<a name='wls_workmanager_constraint_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_workmanager_constraint](#attributes)

### ensure<a name='wls_workmanager_constraint_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_workmanager_constraint](#attributes)

### name<a name='wls_workmanager_constraint_name'>

The name.



[Back to overview of wls_workmanager_constraint](#attributes)

### provider<a name='wls_workmanager_constraint_provider'>

The specific backend to use for this `wls_workmanager_constraint`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage workmanager constraint of a WebLogic domain



[Back to overview of wls_workmanager_constraint](#attributes)

### target<a name='wls_workmanager_constraint_target'>

An array of target names.

The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

    ..{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_workmanager_constraint](#attributes)

### targettype<a name='wls_workmanager_constraint_targettype'>

An array of target types.

The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

    ...{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_workmanager_constraint](#attributes)

### timeout<a name='wls_workmanager_constraint_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_workmanager_constraint](#attributes)

### workmanager_constraint_name<a name='wls_workmanager_constraint_workmanager_constraint_name'>

The workmanager constraint name



[Back to overview of wls_workmanager_constraint](#attributes)
