#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:xa_rollback_local_tx_upon_conn_close, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-EOD
  Enables WebLogic Server to call <code>rollback()</code> on the connection before returning the connection to the connection pool.  Enabling this attribute will have a performance impact as the rollback call requires communication with the database server.  This option is deprecated.  Its value is currently ignored. 

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         xa_rollback_local_tx_upon_conn_close => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:xa_rollback_local_tx_upon_conn_close']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JDBCResource/%{datasource_name}/JDBCXAParams/%{datasource_name}/RollbackLocalTxUponConnClose')
end
