#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:versionidentifier) do
  include EasyType

  defaultto :absent

  desc <<-EOD
  The version identifier.

  EOD

  def insync?(is, refreshing = false)
    if !refreshing
      return true if resource[:refreshonly] == :true
      @called_before = true  # We have already told Puppet everything it needs to know.
    else
      return true if @called_before
    end
    is = '' if is == :absent
    requested_value = absent?(should) ? version_in_ear : should
    synced = is == requested_value
    Puppet.notice "#{path}: #{change_to_s(is, requested_value)} because of refresh." if refreshing && !synced
    synced
  end

  def change_to_s(is, should)
    is = '' if is == :absent
    requested_value = absent?(should) ? version_in_ear : should
    super(is, requested_value)
  end

  to_translate_to_resource do |raw_resource|
    raw_resource['versionidentifier']
  end
end

def versionidentifier
  self[:versionidentifier] == :absent ? version_in_ear : self[:versionidentifier]
end

private

  def absent?(value)
    value.nil? || value == :absent
  end

def version_in_ear
  @version_in_ear ||= open("| unzip -p #{resource[:localpath]} META-INF/MANIFEST.MF | grep WebLogic-Application-Version:").read.split(':')[1].strip
rescue
  ''
end
