#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:exalogic_optimizations_enabled, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-EOD
  Specifies whether optimizations for Oracle Exalogic should be enabled. Optimizations include improved thread management and request processing, and reduced lock contention. This attribute should be enabled only when configuring a WebLogic domain for Oracle Exalogic. 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         exalogic_optimizations_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:exalogic_optimizations_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('ExalogicOptimizationsEnabled')
end
