#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_file_persistence_store) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a file persistence stores in an WebLogic domain.

    Here is an example on how to use the `wls_file_persistence_store`:


        # this will use default as wls_setting identifier
        wls_file_persistence_store{'jmsFile1':
          ensure     => 'present',
          directory  => 'persistence1',
          target     => ['wlsServer1'],
          targettype => ['Server'],
        }

    In this example you are managing a file persistence store in the default domain. When you want to
    manage a file persistence store in a specific domain, you can use:

        wls_file_persistence_store{'mydomain/jmsFile2':
          ensure     => 'present',
          directory  => 'persistence2',
          target     => ['wlsServer2'],
          targettype => ['Server'],
        }

    EOD

    ensurable

    bean_type('FileStore')

    parameter :domain
    parameter :name
    parameter :file_persistence_name
    parameter :timeout
    property :directory
    property :target
    property :targettype
    extraproperties do
      property :block_size
      property :cache_directory
      property :deployment_order
      property :file_locking_enabled
      property :initial_size
      property :io_buffer_size
      property :logical_name
      property :max_file_size
      property :max_window_buffer_size
      property :notes
      property :synchronous_write_policy
      property :xa_resource_name
      property :min_window_buffer_size
      #
      # Weblogic 12.2.1 new properties
      #
      property :distribution_policy
      property :failback_delay_seconds
      property :initial_boot_delay_seconds
      property :migration_policy
      property :number_of_restart_attempts
      property :partial_cluster_stability_delay_seconds
      property :restart_in_place
      property :seconds_between_restarts
      property :tags
    end

    add_title_attributes(:file_persistence_name)
  end
end
