#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:initial_size, :parent => Puppet::Parameter::WlsProperty) do
  

  desc <<-EOD
  The initial file size, in bytes.
  - Set `InitialSize` to pre-allocate file space during a file store boot. If `InitialSize` exceeds `MaxFileSize`, a store creates multiple files (number of files = `InitialSize`/`MaxFileSize` rounded up).
  - A file store automatically reuses the space from deleted records and automatically expands a file if there is not enough space for a new write request.
  - Use `InitialSize` to limit or prevent file expansions during runtime, as file expansion introduces temporary latencies that may be noticeable under rare circumstances.
  - Changes to initial size only take effect for new file stores, or after any current files have been deleted prior to restart.
  -  See <a href='#getMaxFileSize'>Maximum File Size</a>.

  An example on how to use this:

      wls_file_persistence_store {a_wls_file_persistence_store :
         ...
         initial_size => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_file_persistence_store:initial_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('InitialSize')
end
