#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_jdbc_persistence_store) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a JDBC persistence stores in an WebLogic domain.

    Here is an example on how you should use this:

        wls_jdbc_persistence_store { 'JDBCStoreX':
          ensure      => 'present',
          datasource  => 'jmsDS',
          prefix_name => 'dev_',
          target      => ['wlsServer1'],
          targettype  => ['Server'],
        }

    In this example you are managing a JDBC persistance store in the default domain. When you want to
    manage a JDBC persistance store in a specific domain, you can use:

        wls_jdbc_persistence_store { 'my_domain/JDBCStoreX':
          ensure      => 'present',
          datasource  => 'jmsDS',
          prefix_name => 'dev_',
          target      => ['wlsServer1'],
          targettype  => ['Server'],
        }


    EOD

    bean_type('JDBCStore')

    ensurable
    parameter :domain
    parameter :name
    parameter :jdbc_persistence_name
    parameter :timeout

    property :datasource
    property :prefix_name
    property :target
    property :targettype
    extraproperties do
      property :deployment_order
      property :inserts_per_batch_maximum
      property :three_step_threshold
      property :worker_count
      property :worker_preferred_batch_size
      property :create_table_ddl_file
      property :deletes_per_batch_maximum
      property :deletes_per_statement_maximum
      property :logical_name
      property :notes
      property :oracle_piggyback_commit_enabled
      property :xa_resource_name
      #
      # Weblogic 12.2.1 new properties
      #
      property :data_source
      property :distribution_policy
      property :failback_delay_seconds
      property :initial_boot_delay_seconds
      property :migration_policy
      property :number_of_restart_attempts
      property :partial_cluster_stability_delay_seconds
      property :reconnect_retry_interval_millis
      property :reconnect_retry_period_millis
      property :restart_in_place
      property :seconds_between_restarts
      property :tags
    end


    add_title_attributes(:jdbc_persistence_name)
  end
end
