#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:distribution_policy, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Specifies how the instances of a configured JMS artifact are named and distributed when deployed to a cluster. When this setting is configured on a Store it applies to all JMS artifacts that reference the store. Valid options: <ul> <li> <code>Distributed</code> creates an artifact instance on each cluster member in a cluster. Required for all SAF Agents and for cluster targeted or resource group scoped JMS Servers that host distributed destinations. </li>  <li> <code>Singleton</code> creates one artifact instance on a single cluster member of a cluster. Required for cluster targeted or resource group scoped JMS Servers that host standalone (non-distributed) destinations and for cluster targeted or resource group scoped Path Services.  The <code>Migration Policy</code> must be <code>On-Failure</code> or <code>Always</code> when using this option with a JMS Server, <code>On-Failure</code> when using this option with a Messaging Bridge, and <code>Always</code> when using this option with a Path Service. </li> </ul>  The <code>DistributionPolicy</code> determines the instance name suffix for cluster targeted JMS artifacts.  The suffix for a cluster targeted <code>Singleton</code> is <code>-01</code> and for a cluster targeted <code>Distributed</code> is <code>@ClusterMemberName</code>.  

  An example on how to use this:

      wls_jdbc_persistence_store {a_wls_jdbc_persistence_store :
         ...
         distribution_policy => 'Distributed'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jdbc_persistence_store:distribution_policy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('DistributionPolicy')
end
