#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:client_allow_close_in_on_message, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Specifies whether the connection factory creates message consumers that allow a <code>close()</code> method to be issued within its <code>onMessage()</code> method call. <ul> <li> If enabled, a <code>close()</code> method call from within an <code>onMessage()</code> method call will succeed instead of blocking forever. If the acknowledge mode of the session is set to <code>AUTO_ACKNOWLEDGE</code>, the current message will still be acknowledged automatically when the <code>onMessage()</code> call completes.</li> <li> If disabled, it will cause the <code>stop()</code> and <code>close()</code> methods to hang if called from <code>onMessage()</code> .</li> </ul>  This attribute is dynamic and can be changed at any time. However, changing the value does not affect existing connections. It only affects new connections made with this connection factory.  

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         client_allow_close_in_on_message => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:client_allow_close_in_on_message']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('ClientParams/%{connection_factory_name}/AllowCloseInOnMessage')
end
