#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:load_balancing_policy, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-EOD
  Determines how messages are distributed to the members of this destination.  Choose from the following distribution techniques: <ul> <li>Round-Robin The system maintains an ordering of physical topic members within the set by distributing the messaging load across the topic members one at a time in the order that they are defined in the configuration file. Each WebLogic Server instance maintains an identical ordering, but may be at a different point within the ordering. If weights are assigned to any of the topic members in the set, then those members appear multiple times in the ordering.  <li>Random The weight assigned to the topic members is used to compute a weighted distribution for the members of the set. The messaging load is distributed across the topic members by pseudo-randomly accessing the distribution. In the short run, the load will not be directly proportional to the weight. In the long run, the distribution will approach the limit of the distribution. A pure random distribution can be achieved by setting all the weights to the same value, which is typically set to 1. </ul>

  An example on how to use this:

      wls_jms_queue {a_wls_jms_queue :
         ...
         load_balancing_policy => 'Round-Robin'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_queue:load_balancing_policy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('LoadBalancingPolicy')
end
