#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_jms_quota) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a Quota in a JMS module of a WebLogic domain.

    Here is an example on how you should use this:

        wls_jms_quota { 'jmsClusterModule:QuotaBig':
          ensure          => 'present',
          bytesmaximum    => '9223372036854775807',
          messagesmaximum => '9223372036854775807',
          policy          => 'FIFO',
          shared          => 1,,
        }

    In this example you are managing a JMS quota in the default domain. When you want to
    manage a JMS quota in a specific domain, you can use:

        wls_jms_quota { 'my_domain/jmsClusterModule:QuotaLow':
          ensure          => 'present',
          bytesmaximum    => '20000000000',
          messagesmaximum => '9223372036854775807',
          policy          => 'FIFO',
          shared          => '0',
        }

    EOD

    bean_path('/JMSSystemResources/%{jmsmodule}/JMSResource/%{jmsmodule}/Quotas')
    bean_type('Quota')

    ensurable
    parameter :quota_name
    parameter :domain
    parameter :name
    parameter :jmsmodule
    parameter :timeout

    property :bytesmaximum
    property :messagesmaximum
    property :policy
    property :shared
    extraproperties do
      property :bytes_maximum
      property :messages_maximum
      property :notes
      #
      # Weblogic 12.2.1 new properties
      #
    end

    add_title_attributes(:jmsmodule, :quota_name) do
      /(.+):(.+)/
    end
  end
end
