#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:production_paused_at_startup, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Specifies whether production is paused at server startup on destinations targeted to this JMS server. A destination cannot receive any new messages while it is paused.  When the value is set to <code>true</code>, then immediately after the host server instance is rebooted, then this JMS server and its targeted destinations are modified such that they are in a "production paused" state, which results in preventing new message production activities on those destinations.  To resume normal new message production activity, later you will have to change the state of this JMS server to a "production enabled" state by setting this value to <code>false</code>, and then either redeploy the JMS server or reboot the hosting server instance.   When the value is set to <code>default</code>, then the Production Paused At Startup is determined based on the corresponding setting on the individual destination. 

  An example on how to use this:

      wls_jmsserver {a_wls_jmsserver :
         ...
         production_paused_at_startup => 'default'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jmsserver:production_paused_at_startup']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('ProductionPausedAtStartup')
end
