#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ssl_enabled, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Indicates whether the server can be reached through the default SSL listen port.  If the administration port is enabled for the WebLogic Server domain, then administrative traffic travels over the administration port and application traffic travels over the Listen Port and SSL Listen Port. If the administration port is disabled, then all traffic travels over the Listen Port and SSL Listen Port. 

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         ssl_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:ssl_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('SSL/%{server_name}/Enabled')
end
