#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:state) do
  include EasyType

  newvalues(
  'running',
  'starting',
  'standby',
  'admin',
  'resuming',
  'shutting-down',
  'suspening',
  'force_suspend',
  'failed_not_restartable',
  'shutdown')

  desc <<-EOD
  The state of the managed server. 

  The puppet type recognizes all possible states, but it can only manage a
  full start (e.g. move all the way to state `running`) and a full stop. 
  (e.g moving all the way to state `shutdown`). When it is currently `shutdown`,
  setting it to state `admin`  for example, will result in a full start.  


  EOD

  START_STATES = [
    'running',
    'starting',
    'standby',
    'admin',
    'resuming',
  ]
  STOP_STATES  = [
    'shutting-down',
    'suspening',
    'force_suspend',
    'shutdown',
    'failed_not_restartable'
    ]

  def self.translate_to_resource(raw_resource, resource)
    my_resource = raw_resource.merge(resource) # Merge raw with what we got
    wls_config = Puppet_X::EnterpriseModules::WebLogic::Tree.new(my_resource[:domain])
    value = wls_config.get("/ServerLifeCycleRuntimes/#{my_resource[:server_name]}/State", 'domainRuntime')
    value && value.downcase!  # Guard to when a nill is returned
    value
  end

  def insync?(is)
    if should == :running and running?(is)
      Puppet.info "#{resource.name} already in a starting state #{is}, skipping action."
      return true
    elsif should == :shutdown and shutdown?(is)
      Puppet.info "#{resource.name} already in a stopped state #{is}, skipping action."
      return true
    end
    super
  end

  after_create do
    manage_state
  end

  after_modify do
    manage_state
  end
  
  def manage_state
    @wls_config = Puppet_X::EnterpriseModules::WebLogic::Tree.new(resource[:domain])
    if running?(value)
      Puppet.debug "Starting server #{resource.name}..."
      start_server
    elsif shutdown?(value)
      Puppet.debug "Stopping server #{resource.name}..."
      stop_server
    else 
      fail 'Internal error'
    end
  end

  def start_server
    @wls_config.start_server(resource.server_name)
  end

  def stop_server
    @wls_config.stop_server(resource.server_name)
  end

  def shutdown?(is)
    STOP_STATES.include?(is.to_s)
  end

  def running?(is)
    START_STATES.include?(is.to_s)
  end
end